using System.Drawing;
using System.Windows.Forms;
using Dapfor.Net.Editors;
using Dapfor.Net.Grid.Tutorial.BusinessData.OrderBook;
using Dapfor.Net.Ui;
using Appearance = Dapfor.Net.Ui.Appearance;

namespace Dapfor.Net.Grid.Tutorial.Editors
{
    public class OrderStatusEditor : UITypeEditorEx
    {
        public override bool GetPaintCellSupported()
        {
            return true;
        }

        public override void PaintCell(PaintCellEventArgs e)
        {
            Order order = e.Cell.Row.DataObject as Order;
            if (order != null)
            {
                e.Parts ^= e.Parts & PaintPart.Text;
                e.PaintAll();
                e.Handled = true;

                Rectangle bounds = e.Cell.VirtualBounds;
                bounds.Inflate(-2, -1);

                Color backColor = Color.LightGreen;
                string text = "Stop";
                switch (order.Status)
                {
                    case Status.Created:
                    case Status.Cancelled:
                        backColor = ControlPaint.LightLight(Color.OrangeRed);
                        text = "Start";
                        break;
                }

                e.Render.DrawCaption(new Appearance(SystemColors.WindowText, backColor), ElementState.Normal, bounds, BorderSide.All, e.Graphics);
                e.PaintText(text, bounds);
            }
        }

        public override StopEditReason EditCell(IGridEditorService service, Cell cell, StartEditReason reason)
        {
            Order order = cell.Row.DataObject as Order;
            if (order != null)
            {
                switch (order.Status)
                {
                    case Status.Created:
                    case Status.Cancelled:
                        order.Status = Status.Active;
                        break;

                    case Status.Active:
                        order.Status = Status.Cancelled;
                        break;
                }
            }
            return StopEditReason.UserStop;
        }
    }
}